.. _api-models:

Models
======

.. automodule:: guardian.models


.. model:: BaseObjectPermission

BaseObjectPermission
--------------------

.. autoclass:: guardian.models.BaseObjectPermission
   :members:


.. model:: UserObjectPermission

UserObjectPermission
--------------------

.. autoclass:: guardian.models.UserObjectPermission
   :members:


.. model:: GroupObjectPermission

GroupObjectPermission
---------------------

.. autoclass:: guardian.models.GroupObjectPermission
   :members:

